==> driver-babel-0.3.0.tgz: package/esm/BabelDriver.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
/**
 * @copyright   2017, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 * 
 */

import path from 'path';
import rimraf from 'rimraf';
import { Driver } from '@beemo/core';

var BabelDriver = function (_Driver) {
  _inherits(BabelDriver, _Driver);

  function BabelDriver() {
    _classCallCheck(this, BabelDriver);

    return _possibleConstructorReturn(this, (BabelDriver.__proto__ || Object.getPrototypeOf(BabelDriver)).apply(this, arguments));
  }

  _createClass(BabelDriver, [{
    key: 'bootstrap',
    value: function bootstrap() {
      this.setMetadata({
        bin: 'babel',
        configName: '.babelrc',
        description: 'Transpile files with Babel.',
        title: 'Babel'
      }).on('execute', this.handleExecute);
    }
  }, {
    key: 'bootstrapCommand',
    value: function bootstrapCommand(command) {
      command.option('clean', {
        boolean: true,
        default: true,
        describe: 'Clean the target folder'
      });
    }
  }, {
    key: 'handleExecute',
    value: function handleExecute(event, driver, args, options) {
      if (!options.clean || !options.ourDir) {
        return;
      }

      if (options.clean && options.ourDir) {
        rimraf.sync(path.resolve(options.outDir));
      }
    }
  }]);

  return BabelDriver;
}(Driver);

export default BabelDriver;

==> driver-babel-0.7.0.tgz: package/esm/BabelDriver.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
/**
 * @copyright   2017, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 * 
 */

import path from 'path';
import rimraf from 'rimraf';
import { Driver } from '@beemo/core';

var BabelDriver = function (_Driver) {
  _inherits(BabelDriver, _Driver);

  function BabelDriver() {
    _classCallCheck(this, BabelDriver);

    return _possibleConstructorReturn(this, (BabelDriver.__proto__ || Object.getPrototypeOf(BabelDriver)).apply(this, arguments));
  }

  _createClass(BabelDriver, [{
    key: 'bootstrap',
    value: function bootstrap() {
      this.setMetadata({
        bin: 'babel',
        configName: '.babelrc',
        description: 'Transpile files with Babel.',
        title: 'Babel'
      }).on('execute', this.handleExecute);
    }
  }, {
    key: 'bootstrapCommand',
    value: function bootstrapCommand(command) {
      command.option('clean', {
        boolean: true,
        default: true,
        describe: 'Clean the target folder'
      });
    }
  }, {
    key: 'handleExecute',
    value: function handleExecute(event, driver, args, options) {
      if (options.clean && options.outDir) {
        rimraf.sync(path.resolve(options.outDir));
      }
    }
  }]);

  return BabelDriver;
}(Driver);

export default BabelDriver;
